const config = require("./config.json");

const { Client } = require("rustrcon");

const Discord = require("discord.js");

const fetch = require('node-fetch');

const chalk = require('chalk');

let serverIP = "";

config.SERVERS.forEach(async (server) => {

  server.rcon = new Client({
    ip: server.RCON_IP,
    port: server.RCON_PORT,
    password: server.RCON_PASS,
  });

  server.connected = false;

  server.playerCountUpdate = null;

  server.scheduler = null;

  serverIP = `${server.rcon.ws.ip}:${server.rcon.ws.port}`;

  attemptConnection();


  server.rcon.on("connected", () => {

    server.connected = true;

    console.log(`💚 successfully connected to -- ${chalk.cyan(serverIP)}`);
  
});

  server.rcon.on("error", (err) => {

    logError(err.message);

  });

  function logError(err) {

    console.log(`❤️ There was an issue while connecting to ${chalk.red(serverIP)}...\n\n---------[${chalk.red('ERROR')}]---------\n\n${err}\n\n-------------------------\n`);

  }

  server.rcon.on("disconnect", () => {

    if (server.connected) {

        server.connected = false;

    } else {

      console.log(`💛 Attempting to connect to ${chalk.cyan(serverIP)}`);

    }

    attemptConnection();
  });

  let re = /7656119([0-9]{10})/gm;
  let bansArray = [];
  server.rcon.on("message", async (message) => {
    
    if(message.Identifier === 0 && typeof message.content !== 'object') {
      if(message.content.includes("joined")) {

        let results = message.content.match(re);
        if(results !== null) {

          if(server.IGNORE_USERS_FROM_TEMP_CHECK.find(steam => results == steam)) return;

          fetch(`https://rustbans.com/api/${results[0]}`).then(res => res.json()).then(response => {
            if (response == "Steam ID length is not correct.") return;
            console.log(JSON.stringify(response));

            response.forEach(ban => {
              console.log(ban);
              if(ban.Banned) {
                let banTime = response[0].BanDateMilliseconds / 1000;
                bansArray.push(`> **Temp banned:** <t:${banTime}:R>\n> **Tweet:** ${ban.TweetLink}`);
              }
            });

            if(bansArray.length > 0) {
              let hook = new Discord.WebhookClient({ url: server.PLAYER_TEMP_BAN_WEBHOOK });

              fetch(`http://api.steampowered.com/ISteamUser/GetPlayerSummaries/v0002/?key=${config.STEAM_API_KEY}&steamids=${results[0]}`).then(res => res.text()).then(steam => {
                try {
                  steam = JSON.parse(steam);  
                    if(!steam.response.players[0]) {
                      return;
                    }

                  const { personaname, avatarfull, profileurl, steamid } = steam.response.players[0];

                  const embed = new Discord.MessageEmbed()
                  .setAuthor({ name: `Temp bans detected on ${personaname}`, url: `https://steamcommunity.com/profiles/${steamid}/`, iconURL: avatarfull })
                  .setThumbnail(avatarfull)
                  .setDescription(bansArray.join("\n\n"))
                  .setTimestamp()
                  .setFooter({ text: `(${steamid}) Detected` })
                  .setColor(server.EMBED_COLOR)
    
                hook.send({ embeds: [embed] });
                  } catch (err) {

                  }

              });
            }
          });
        }

      }
    }

  });

  function attemptConnection() {

    console.log(`💛 Attempting to connect to ${chalk.cyan(serverIP)}`);

    server.rcon.login();

  }
  
});
